==> seamonkey-2.53.18.source.tar.xz: seamonkey-2.53.18/devtools/client/memory/test/unit/test_action-clear-snapshots_05.js <==
/* Any copyright is dedicated to the Public Domain.
   http://creativecommons.org/publicdomain/zero/1.0/ */

"use strict";

// Test clearSnapshots deletes several snapshots

let { takeSnapshotAndCensus, clearSnapshots } = require("devtools/client/memory/actions/snapshot");
let { actions, treeMapState } = require("devtools/client/memory/constants");

add_task(function* () {
  let front = new StubbedMemoryFront();
  let heapWorker = new HeapAnalysesClient();
  yield front.attach();
  let store = Store();
  const { getState, dispatch } = store;

  ok(true, "create 2 snapshots with a saved census");
  dispatch(takeSnapshotAndCensus(front, heapWorker));
  dispatch(takeSnapshotAndCensus(front, heapWorker));
  ok(true, "snapshots created with a saved census");
  yield waitUntilCensusState(store, snapshot => snapshot.treeMap,
                             [treeMapState.SAVED, treeMapState.SAVED]);

  let errorHeapWorker = {
    deleteHeapSnapshot: function () {
      return Promise.reject("_");
    }
  };

  ok(true, "dispatch clearSnapshots action");
  let deleteEvents = Promise.all([
    waitUntilAction(store, actions.DELETE_SNAPSHOTS_START),
    waitUntilAction(store, actions.DELETE_SNAPSHOTS_END),
    waitUntilAction(store, actions.SNAPSHOT_ERROR),
    waitUntilAction(store, actions.SNAPSHOT_ERROR),
  ]);
  dispatch(clearSnapshots(errorHeapWorker));
  yield deleteEvents;
  ok(true, "received delete snapshots and snapshot error events");
  equal(getState().snapshots.length, 0, "no snapshot remaining");

  heapWorker.destroy();
  yield front.detach();
});

==> seamonkey-2.53.23.source.tar.xz: seamonkey-2.53.23/devtools/client/memory/test/unit/test_action-clear-snapshots_05.js <==
/* Any copyright is dedicated to the Public Domain.
   http://creativecommons.org/publicdomain/zero/1.0/ */

"use strict";

// Test clearSnapshots deletes several snapshots

let { takeSnapshotAndCensus, clearSnapshots } = require("devtools/client/memory/actions/snapshot");
let { actions, treeMapState } = require("devtools/client/memory/constants");

add_task(async function() {
  let front = new StubbedMemoryFront();
  let heapWorker = new HeapAnalysesClient();
  await front.attach();
  let store = Store();
  const { getState, dispatch } = store;

  ok(true, "create 2 snapshots with a saved census");
  dispatch(takeSnapshotAndCensus(front, heapWorker));
  dispatch(takeSnapshotAndCensus(front, heapWorker));
  ok(true, "snapshots created with a saved census");
  await waitUntilCensusState(store, snapshot => snapshot.treeMap,
                             [treeMapState.SAVED, treeMapState.SAVED]);

  let errorHeapWorker = {
    deleteHeapSnapshot: function() {
      return Promise.reject("_");
    }
  };

  ok(true, "dispatch clearSnapshots action");
  let deleteEvents = Promise.all([
    waitUntilAction(store, actions.DELETE_SNAPSHOTS_START),
    waitUntilAction(store, actions.DELETE_SNAPSHOTS_END),
    waitUntilAction(store, actions.SNAPSHOT_ERROR),
    waitUntilAction(store, actions.SNAPSHOT_ERROR),
  ]);
  dispatch(clearSnapshots(errorHeapWorker));
  await deleteEvents;
  ok(true, "received delete snapshots and snapshot error events");
  equal(getState().snapshots.length, 0, "no snapshot remaining");

  heapWorker.destroy();
  await front.detach();
});
